@@ -100,27 +100,35 @@ sub Run {
             );
 
             # Set new owner if ticket owner is different then logged user.
-            if ( $Lock && ( $Ticket{OwnerID} != $Self->{UserID} ) ) {
+            if ($Lock) {
 
-                # Remember previous owner, which will be used to restore ticket owner on undo action.
-                $Param{PreviousOwner} = $Ticket{OwnerID};
+                # Set new owner if ticket owner is different then logged user.
+                if ( $Ticket{OwnerID} != $Self->{UserID} ) {
 
-                my $Success = $TicketObject->TicketOwnerSet(
-                    TicketID  => $Self->{TicketID},
-                    UserID    => $Self->{UserID},
-                    NewUserID => $Self->{UserID},
-                );
+                    # Remember previous owner, which will be used to restore ticket owner on undo action.
+                    $Param{PreviousOwner} = $Ticket{OwnerID};
 
-                # Show lock state.
-                if ($Success) {
-                    $LayoutObject->Block(
-                        Name => 'PropertiesLock',
-                        Data => {
-                            %Param,
-                            TicketID => $Self->{TicketID}
-                        },
+                    $TicketObject->TicketOwnerSet(
+                        TicketID  => $Self->{TicketID},
+                        UserID    => $Self->{UserID},
+                        NewUserID => $Self->{UserID},
                     );
                 }
+
+                $LayoutObject->Block(
+                    Name => 'PropertiesLock',
+                    Data => {
+                        %Param,
+                        TicketID => $Self->{TicketID}
+                    },
+                );
+                $LayoutObject->Block(
+                    Name => 'PropertiesLockNotify',
+                    Data => {
+                        %Param,
+                        TicketID => $Self->{TicketID}
+                    },
+                );
             }
         }
         else {
@@ -147,7 +155,10 @@ sub Run {
             # show back link
             $LayoutObject->Block(
                 Name => 'TicketBack',
-                Data => { %Param, TicketID => $Self->{TicketID} },
+                Data => {
+                    %Param,
+                    TicketID => $Self->{TicketID}
+                },
             );
         }
     }
@@ -156,7 +167,10 @@ sub Run {
         # show back link
         $LayoutObject->Block(
             Name => 'TicketBack',
-            Data => { %Param, TicketID => $Self->{TicketID} },
+            Data => {
+                %Param,
+                TicketID => $Self->{TicketID}
+            },
         );
     }
 
