@@ -927,6 +927,13 @@ sub Run {
                             TicketID => $Self->{TicketID}
                         },
                     );
+                    $LayoutObject->Block(
+                        Name => 'PropertiesLockNotify',
+                        Data => {
+                            %Param,
+                            TicketID => $Self->{TicketID},
+                        },
+                    );
                     $TicketUnlock = 1;
                 }
             }
@@ -1530,7 +1537,7 @@ sub AgentMove {
 
     if ( $Config->{Note} ) {
 
-        $Param{WidgetStatus} = 'Collapsed';
+        $Param{CardStatus} = 'cardClosed';
 
         if (
             $Config->{NoteMandatory}
@@ -1539,7 +1546,7 @@ sub AgentMove {
             || $Param{CreateArticle}
             )
         {
-            $Param{WidgetStatus} = 'Expanded';
+            $Param{CardStatus} = '';
         }
 
         if (
@@ -1573,6 +1580,29 @@ sub AgentMove {
             );
         }
 
+        my $PreviewContentTypes = $ConfigObject->Get('Attachment')->{PreviewContentTypes} || {};
+
+        # show attachments
+        ATTACHMENT:
+        for my $Attachment ( @{ $Param{Attachments} } ) {
+            if (
+                $Attachment->{ContentID}
+                && $LayoutObject->{BrowserRichText}
+                && ( $Attachment->{ContentType} =~ /image/i )
+                && ( $Attachment->{Disposition} eq 'inline' )
+                )
+            {
+                next ATTACHMENT;
+            }
+
+            # Add preview flag if content type is in the preview content types list.
+            # This is used to determine if the attachment can be previewed in the UI.
+            if ( $Attachment->{ContentType} && $PreviewContentTypes->{ $Attachment->{ContentType} } ) {
+                $Attachment->{Preview} = 1;
+            }
+            push @{ $Param{AttachmentList} }, $Attachment;
+        }
+
         $LayoutObject->Block(
             Name => 'Note',
             Data => {%Param},
@@ -1617,22 +1647,6 @@ sub AgentMove {
             );
         }
 
-        # show attachments
-        ATTACHMENT:
-        for my $Attachment ( @{ $Param{Attachments} } ) {
-            if (
-                $Attachment->{ContentID}
-                && $LayoutObject->{BrowserRichText}
-                && ( $Attachment->{ContentType} =~ /image/i )
-                && ( $Attachment->{Disposition} eq 'inline' )
-                )
-            {
-                next ATTACHMENT;
-            }
-
-            push @{ $Param{AttachmentList} }, $Attachment;
-        }
-
         # add rich text editor
         if ( $LayoutObject->{BrowserRichText} ) {
 
