@@ -1566,6 +1566,8 @@ sub _Mask {
             );
         }
 
+        my $PreviewContentTypes = $ConfigObject->Get('Attachment')->{PreviewContentTypes} || {};
+
         # show attachments
         # get all attachments meta data
         my @Attachments = $UploadCacheObject->FormIDGetAllFilesMeta(
@@ -1584,6 +1586,12 @@ sub _Mask {
                 next ATTACHMENT;
             }
 
+            # Add preview flag if content type is in the preview content types list.
+            # This is used to determine if the attachment can be previewed in the UI.
+            if ( $Attachment->{ContentType} && $PreviewContentTypes->{ $Attachment->{ContentType} } ) {
+                $Attachment->{Preview} = 1;
+            }
+
             push @{ $Param{AttachmentList} }, $Attachment;
         }
     }
