@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,13 +18,12 @@ our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Calendar',
     'Kernel::System::Calendar::Appointment',
+    'Kernel::System::CalendarTemplateGenerator',
     'Kernel::System::DateTime',
     'Kernel::System::Group',
     'Kernel::System::JSON',
     'Kernel::System::Log',
     'Kernel::System::NotificationEvent',
-    'Kernel::System::CalendarTemplateGenerator',
-    'Kernel::System::Ticket',
     'Kernel::System::User',
 );
 
@@ -233,8 +232,8 @@ sub Run {
                 }
 
                 my $Success = $Self->_SendRecipientNotification(
-                    AppointmentID => $Appointment{AppointmentID} || '',
-                    CalendarID    => $Calendar{CalendarID}       || $Appointment{CalendarID} || '',
+                    AppointmentID         => $Appointment{AppointmentID} || '',
+                    CalendarID            => $Calendar{CalendarID} || $Appointment{CalendarID} || '',
                     Notification          => $Bundle->{Notification},
                     CustomerMessageParams => $Param{Data}->{CustomerMessageParams} || {},
                     Recipient             => $Bundle->{Recipient},
@@ -269,8 +268,8 @@ sub Run {
                 );
 
                 my $Success = $Self->_SendRecipientNotification(
-                    AppointmentID => $Appointment{AppointmentID} || '',
-                    CalendarID    => $Calendar{CalendarID}       || $Appointment{CalendarID} || '',
+                    AppointmentID         => $Appointment{AppointmentID} || '',
+                    CalendarID            => $Calendar{CalendarID} || $Appointment{CalendarID} || '',
                     Notification          => \%ReplacedNotification,
                     CustomerMessageParams => $Param{Data}->{CustomerMessageParams} || {},
                     Recipient             => $Recipient,
@@ -302,31 +301,40 @@ sub _NotificationFilter {
 
     return if !IsHashRefWithData( $Notification{Data} );
 
+    my @KeysToIgnore = qw(
+        Recipients
+        SkipRecipients
+        RecipientAgents
+        RecipientGroups
+        RecipientRoles
+        TransportEmailTemplate
+        Events
+        ArticleTypeID
+        ArticleSenderTypeID
+        ArticleSubjectMatch
+        ArticleBodyMatch
+        ArticleAttachmentInclude
+        NotificationArticleTypeID
+        Transports
+        OncePerDay
+        VisibleForAgent
+        VisibleForAgentTooltip
+        LanguageID
+        SendOnOutOfOffice
+        AgentEnabledByDefault
+        NotificationType
+        EmailSecuritySettings
+        EmailSigningCrypting
+        EmailMissingSigningKeys
+        EmailMissingCryptingKeys
+    );
+    my %KeysToIgnore = map { $_ => 1 } @KeysToIgnore;
+
     KEY:
     for my $Key ( sort keys %{ $Notification{Data} } ) {
 
         # ignore not appointment related attributes
-        next KEY if $Key eq 'Recipients';
-        next KEY if $Key eq 'SkipRecipients';
-        next KEY if $Key eq 'RecipientAgents';
-        next KEY if $Key eq 'RecipientGroups';
-        next KEY if $Key eq 'RecipientRoles';
-        next KEY if $Key eq 'TransportEmailTemplate';
-        next KEY if $Key eq 'Events';
-        next KEY if $Key eq 'ArticleTypeID';
-        next KEY if $Key eq 'ArticleSenderTypeID';
-        next KEY if $Key eq 'ArticleSubjectMatch';
-        next KEY if $Key eq 'ArticleBodyMatch';
-        next KEY if $Key eq 'ArticleAttachmentInclude';
-        next KEY if $Key eq 'NotificationArticleTypeID';
-        next KEY if $Key eq 'Transports';
-        next KEY if $Key eq 'OncePerDay';
-        next KEY if $Key eq 'VisibleForAgent';
-        next KEY if $Key eq 'VisibleForAgentTooltip';
-        next KEY if $Key eq 'LanguageID';
-        next KEY if $Key eq 'SendOnOutOfOffice';
-        next KEY if $Key eq 'AgentEnabledByDefault';
-        next KEY if $Key eq 'NotificationType';
+        next KEY if $KeysToIgnore{$Key};
 
         # check recipient fields from transport methods
         if ( $Key =~ m{\A Recipient}xms ) {
