@@ -167,8 +167,8 @@ sub DynamicFieldAdd {
             ' config, valid_id, create_time, create_by, change_time, change_by)' .
             ' VALUES (?, ?, ?, ?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
-            \$InternalField, \$Param{Name}, \$Param{Label}, \$Param{FieldOrder}, \$Param{FieldType},
-            \$Param{ObjectType}, \$Config, \$Param{ValidID}, \$Param{UserID}, \$Param{UserID},
+            \$InternalField,     \$Param{Name}, \$Param{Label},   \$Param{FieldOrder}, \$Param{FieldType},
+            \$Param{ObjectType}, \$Config,      \$Param{ValidID}, \$Param{UserID},     \$Param{UserID},
         ],
     );
 
@@ -445,16 +445,31 @@ sub DynamicFieldUpdate {
         $ChangedOrder = 1;
     }
 
-    # sql
-    return if !$DBObject->Do(
-        SQL => 'UPDATE dynamic_field SET name = ?, label = ?, field_order =?, field_type = ?, '
-            . 'object_type = ?, config = ?, valid_id = ?, change_time = current_timestamp, '
-            . ' change_by = ? WHERE id = ?',
-        Bind => [
-            \$Param{Name}, \$Param{Label}, \$Param{FieldOrder}, \$Param{FieldType},
-            \$Param{ObjectType}, \$Config, \$Param{ValidID}, \$Param{UserID}, \$Param{ID},
-        ],
-    );
+    # InternalField is never set via the GUI (e.g. AdminDynamicFieldText.pm)
+    # If it is set via the "Backend" for example PackageSetup
+    # it should also be possible to change the 'InternalField' again.
+    if ( defined $Param{InternalField} ) {
+        return if !$DBObject->Do(
+            SQL => 'UPDATE dynamic_field SET internal_field = ?, name = ?, label = ?, field_order =?, field_type = ?, '
+                . 'object_type = ?, config = ?, valid_id = ?, change_time = current_timestamp, '
+                . ' change_by = ? WHERE id = ?',
+            Bind => [
+                \$Param{InternalField}, \$Param{Name}, \$Param{Label},   \$Param{FieldOrder}, \$Param{FieldType},
+                \$Param{ObjectType},    \$Config,      \$Param{ValidID}, \$Param{UserID},     \$Param{ID},
+            ],
+        );
+    }
+    else {
+        return if !$DBObject->Do(
+            SQL => 'UPDATE dynamic_field SET name = ?, label = ?, field_order =?, field_type = ?, '
+                . 'object_type = ?, config = ?, valid_id = ?, change_time = current_timestamp, '
+                . ' change_by = ? WHERE id = ?',
+            Bind => [
+                \$Param{Name}, \$Param{Label}, \$Param{FieldOrder}, \$Param{FieldType},
+                \$Param{ObjectType}, \$Config, \$Param{ValidID}, \$Param{UserID}, \$Param{ID},
+            ],
+        );
+    }
 
     # get cache object
     my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
@@ -879,16 +894,16 @@ Returns:
 
     $List = (
         {
-            ID          => 123,
+            ID            => 123,
             InternalField => 0,
-            Name        => 'nameforfield',
-            Label       => 'The label to show',
-            FieldType   => 'Text',
-            ObjectType  => 'Article',
-            Config      => $ConfigHashRef,
-            ValidID     => 1,
-            CreateTime  => '2011-02-08 15:08:00',
-            ChangeTime  => '2011-06-11 17:22:00',
+            Name          => 'nameforfield',
+            Label         => 'The label to show',
+            FieldType     => 'Text',
+            ObjectType    => 'Article',
+            Config        => $ConfigHashRef,
+            ValidID       => 1,
+            CreateTime    => '2011-02-08 15:08:00',
+            ChangeTime    => '2011-06-11 17:22:00',
         },
         {
             ID            => 321,
@@ -1129,8 +1144,8 @@ checks for duplicate order numbers and gaps in the numbering.
 
 Returns:
 
-    $Success = 1;                       # or 0 in case duplicates or gaps in the dynamic fields
-                                        #    order numbering
+    $Success = 1;   # or 0 in case duplicates or gaps in the dynamic fields
+                    # order numbering
 
 =cut
 
@@ -1178,11 +1193,11 @@ NOTE: Only use object mappings for dynamic fields that must support non-integer
 like customer user logins and customer company IDs.
 
     my $ObjectMapping = $DynamicFieldObject->ObjectMappingGet(
-        ObjectName            => $ObjectName,    # Name or array ref of names of the object(s) to get the ID(s) for
+        ObjectName => $ObjectName,    # Name or array ref of names of the object(s) to get the ID(s) for
                                                  # Note: either give ObjectName or ObjectID
-        ObjectID              => $ObjectID,      # ID or array ref of IDs of the object(s) to get the name(s) for
+        ObjectID   => $ObjectID,      # ID or array ref of IDs of the object(s) to get the name(s) for
                                                  # Note: either give ObjectName or ObjectID
-        ObjectType            => 'CustomerUser', # Type of object to get mapping for
+        ObjectType => 'CustomerUser', # Type of object to get mapping for
     );
 
     Returns for parameter ObjectID:
