@@ -234,6 +234,14 @@ sub _TasksGet {
             Message => 'Check database default storage engine',
             Module  => 'scripts::Migration::Base::DatabaseDefaultStorageEngineCheck',
         },
+
+        # 7.3 specific tasks before database migration
+        {
+            Message => 'Phone state settings migration notice',
+            Module  => 'scripts::Migration::Znuny::MigratePhoneStateSettings',
+        },
+
+        # Base
         {
             Message => 'Upgrade database structure',
             Module  => 'scripts::Migration::Znuny::UpgradeDatabaseStructure',
@@ -250,6 +258,11 @@ sub _TasksGet {
             Message => 'Rebuild configuration',
             Module  => 'scripts::Migration::Base::RebuildConfig',
         },
+
+        # 7.3 specific tasks after database migration
+        # ...to be added here...
+
+        # Base tasks after database migration
         {
             Message => 'Migrate DBCRUD UUID columns',
             Module  => 'scripts::Migration::Znuny::MigrateDBCRUDUUIDColumns',
@@ -270,6 +283,10 @@ sub _TasksGet {
             Module  => 'scripts::Migration::Znuny::RemoveMentionFlagFromArchivedTickets',
         },
 
+        # 7.3 specific tasks after SysConfig migration
+        # ...to be added here...
+
+        # Base tasks after SysConfig migration
         {
             Message => 'Initialize default cron jobs',
             Module  => 'scripts::Migration::Base::InitializeDefaultCronjobs',
@@ -294,7 +311,6 @@ sub _TasksGet {
             Message => 'Check invalid settings',
             Module  => 'scripts::Migration::Base::InvalidSettingsCheck',
         },
-
     );
 
     return @Tasks;
