@@ -764,10 +764,11 @@ Core.UI.Popup = (function (TargetNS) {
         // if this window is a popup itself, register another function
         if (CurrentIsPopupWindow()) {
             Core.UI.Popup.InitRegisterPopupAtParentWindow();
-            $('.CancelClosePopup').on('click', function () {
+            // Use event delegation to handle dynamically created elements
+            $(document).on('click', '.CancelClosePopup', function () {
                 TargetNS.ClosePopup();
             });
-            $('.UndoClosePopup').on('click', function () {
+            $(document).on('click', '.UndoClosePopup', function () {
                 var RedirectURL = $(this).attr('href'),
                     ParentWindow = GetWindowParentObject();
                 ParentWindow.Core.UI.Popup.FirePopupEvent('URL', { URL: RedirectURL });
